Package 'usportsR'

Title: Access U SPORTS data
Description: a package to extract and analyze data from U SPORTS, the governing body of university sport in Canada.
Authors: Shamar Phillips [aut, cre], Matthew Chow [aut] (ORCID: <https://orcid.org/0009-0009-6045-6839>), Rithika Silva [aut], Pierre Aucoin [aut] (ORCID: <https://orcid.org/0009-0003-9739-6485>), David Awosoga [aut] (ORCID: <https://orcid.org/0000-0002-2741-5770>), University of Waterloo Analytics Group for Games and Sports (UWAGGS) [cph]
Maintainer: Shamar Phillips <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9000
Built: 2026-05-29 07:37:08 UTC
Source: https://github.com/uwaggs/usportsr

Help Index


Get U SPORTS basketball pbp data

Description

Get U SPORTS basketball pbp data

Usage

basketball_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

basketball_pbp("m",2018)

Get U SPORTS basketball player box scores

Description

Get U SPORTS basketball player box scores

Usage

basketball_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

basketball_player_box_score("m",2018)

Get U SPORTS basketball schedule

Description

Get U SPORTS basketball schedule

Usage

basketball_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

basketball_schedule("m")

Get U SPORTS basketball team box scores

Description

Get U SPORTS basketball team box scores

Usage

basketball_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

basketball_team_box_score("m",2018)

Get U SPORTS field hockey pbp

Description

Get U SPORTS field hockey pbp

Usage

field_hockey_pbp(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

field_hockey_pbp(2018)

Get U SPORTS field hockey player box scores

Description

Get U SPORTS field hockey player box scores

Usage

field_hockey_player_box_score(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

field_hockey_player_box_score(2018)

Get U SPORTS field hockey schedule

Description

Get U SPORTS field hockey schedule

Usage

field_hockey_schedule()

Value

A tibble.

Examples

field_hockey_schedule()

Get U SPORTS field hockey team box scores

Description

Get U SPORTS field hockey team box scores

Usage

field_hockey_team_box_score(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

field_hockey_team_box_score(2018)

Get U SPORTS football defence stats

Description

Get U SPORTS football defence stats

Usage

football_defence(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

football_defence(2018)

Get U SPORTS football drive summaries

Description

Get U SPORTS football drive summaries

Usage

football_drive_summaries(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

football_drive_summaries(2018)

Get U SPORTS football kicking stats

Description

Get U SPORTS football kicking stats

Usage

football_kicking(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

football_kicking(2018)

Get U SPORTS football offence stats

Description

Get U SPORTS football offence stats

Usage

football_offence(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

football_offence(2018)

Get U SPORTS football pbp

Description

Get U SPORTS football pbp

Usage

football_pbp(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

football_pbp(2018)

Get U SPORTS football returns stats

Description

Get U SPORTS football returns stats

Usage

football_returns(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

football_returns(2018)

Get USPORTS football schedule

Description

Get USPORTS football schedule

Usage

football_schedule()

Value

A tibble.

Examples

football_schedule()

Get U SPORTS football scoring summaries

Description

Get U SPORTS football scoring summaries

Usage

football_scoring_summaries(year = c())

Arguments

year

The season(s) of interest.

Value

A tibble.

Examples

football_scoring_summaries(2018)

Get U SPORTS hockey pbp

Description

Get U SPORTS hockey pbp

Usage

hockey_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

hockey_pbp("m",2018)

Get U SPORTS hockey player box scores

Description

Get U SPORTS hockey player box scores

Usage

hockey_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

hockey_player_box_score("m",2018)

Get U SPORTS hockey schedules

Description

Get U SPORTS hockey schedules

Usage

hockey_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

hockey_schedule("m")

Get U SPORTS hockey team box scores

Description

Get U SPORTS hockey team box scores

Usage

hockey_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

hockey_team_box_score("m",2018)

reads a csv from a url with a csv

Description

reads a csv from a url with a csv

Usage

read_csv(file_url)

Arguments

file_url

A URL to a CSV file.

Value

A data frame with the first few rows of the CSV file.


Get U SPORTS rugby schedule

Description

Get U SPORTS rugby schedule

Usage

rugby_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

rugby_schedule("m")
rugby_schedule("w")

Get U SPORTS soccer play by play data

Description

Get U SPORTS soccer play by play data

Usage

soccer_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

soccer_pbp("m",2018)

Get U SPORTS soccer player box score data

Description

Get U SPORTS soccer player box score data

Usage

soccer_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

soccer_player_box_score("m",2018)

Get U SPORTS soccer schedule

Description

Get U SPORTS soccer schedule

Usage

soccer_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

soccer_schedule("m")

Get U SPORTS soccer team box score data

Description

Get U SPORTS soccer team box score data

Usage

soccer_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

soccer_team_box_score("m",2018)

Get U SPORTS swimming athletes rankings

Description

Get U SPORTS swimming athletes rankings

Usage

swimming_athlete_rankings()

Value

A tibble.

Examples

swimming_athlete_rankings()

Get U SPORTS swimming team rankings

Description

Get U SPORTS swimming team rankings

Usage

swimming_team_rankings()

Value

A tibble.

Examples

swimming_team_rankings()

Get U SPORTS track and field athlete rankings

Description

Get U SPORTS track and field athlete rankings

Usage

tnf_athlete_rankings()

Value

A tibble.

Examples

tnf_athlete_rankings()

Get U SPORTS track and field meet results

Description

Get U SPORTS track and field meet results

Usage

tnf_meet_results()

Value

A tibble.

Examples

tnf_meet_results()

Get U SPORTS track and field rosters

Description

Get U SPORTS track and field rosters

Usage

tnf_rosters()

Value

A tibble.

Examples

tnf_rosters()

Get U SPORTS track and field team rankings

Description

Get U SPORTS track and field team rankings

Usage

tnf_team_rankings()

Value

A tibble.

Examples

tnf_team_rankings()

Get U SPORTS track and field universities

Description

Get U SPORTS track and field universities

Usage

tnf_universities()

Value

A tibble.

Examples

tnf_universities()

Get U SPORTS volleyball play by play data

Description

Get U SPORTS volleyball play by play data

Usage

volleyball_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

volleyball_pbp("m",2018)

Get U SPORTS volleyball player box scores

Description

Get U SPORTS volleyball player box scores

Usage

volleyball_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

A tibble.

Examples

volleyball_player_box_score("m",2018)

Get U SPORTS volleyball schedule

Description

Get U SPORTS volleyball schedule

Usage

volleyball_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

volleyball_schedule("m")

Get U SPORTS volleyball team box scores

Description

Get U SPORTS volleyball team box scores

Usage

volleyball_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest

Value

A tibble.

Examples

volleyball_team_box_score("m",2018)

Get U SPORTS wrestling athletes rankings

Description

Get U SPORTS wrestling athletes rankings

Usage

wrestling_athlete_rankings(gender, weight)

Arguments

gender

Gender of athletes "m" or "w"

weight

weight class

Value

A tibble.

Examples

wrestling_athlete_rankings("m",90)
wrestling_athlete_rankings("w",54)

Get U SPORTS wrestling team rankings

Description

Get U SPORTS wrestling team rankings

Usage

wrestling_team_rankings(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

wrestling_team_rankings("m")
wrestling_team_rankings("w")

Get U SPORTS XC meet results

Description

Get U SPORTS XC meet results

Usage

xc_meet_results()

Value

A tibble.

Examples

xc_meet_results()

Get U SPORTS XC Rosters

Description

Get U SPORTS XC Rosters

Usage

xc_rosters()

Value

A tibble.

Examples

xc_rosters()

Get U SPORTS XC Team Rankings

Description

Get U SPORTS XC Team Rankings

Usage

xc_team_rankings()

Value

A tibble.

Examples

xc_team_rankings()

Get U SPORTS XC Teams

Description

Get U SPORTS XC Teams

Usage

xc_universities()

Value

A tibble.

Examples

xc_universities()