Title: Access U SPORTS Data
Version: 1.0.0
Description: Tools package to extract and analyze data from U SPORTS, the governing body of university sport in Canada.
License: MIT + file LICENSE
Imports: dplyr, magrittr, tibble
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: https://github.com/uwaggs/usportsR, https://uwaggs.github.io/usportsR/
BugReports: https://github.com/uwaggs/usportsR/issues
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-03-09 17:03:51 UTC; pierreaucoin
Author: Shamar Phillips [aut, cre], Matthew Chow ORCID iD [aut], Rithika Silva [aut], Aucoin Pierre ORCID iD [aut], David Awosoga ORCID iD [aut], University of Waterloo Analytics Group for Games and Sports (UWAGGS) [cph]
Maintainer: Shamar Phillips <slphilli@uwaterloo.ca>
Repository: CRAN
Date/Publication: 2026-03-16 15:50:02 UTC

Get U SPORTS basketball play by play data

Description

Get U SPORTS basketball play by play data

Usage

basketball_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
time chr
away chr
away_score int
home_score int
home chr
quarter chr
game_id chr
away_team chr
home_team chr
season chr
season_type chr

Examples

try(basketball_pbp("m",2018))

Get U SPORTS basketball player box scores

Description

Get U SPORTS basketball player box scores

Usage

basketball_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
player chr
min int
fgm int
fga int
three_pm int
three_pa int
ftm int
fta int
oreb int
dreb int
reb int
ast int
stl int
blk int
to int
pf int
pts int
starter int
player_number int
player_links chr
date chr
game_id chr
team_name chr
season chr
season_type chr

Examples

try(basketball_player_box_score("m",2018))

Get U SPORTS basketball schedule

Description

Get U SPORTS basketball schedule

Usage

basketball_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

Column Name Type
league chr
season chr
game_id chr
date Date
exhibition lgl
home_team chr
away_team chr
home_score int
away_score int
game_url chr

Examples

try(basketball_schedule("m"))

Get U SPORTS basketball team box scores

Description

Get U SPORTS basketball team box scores

Usage

basketball_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
field_goals_made int
field_goals_attempted int
field_goal_percentage chr
three_point_field_goals_made int
three_point_field_goals_attempted int
three_point_field_goal_percentage chr
free_throws_made int
free_throws_attempted int
free_throw_percentage chr
rebounds int
assists int
turnovers int
points_off_turnovers int
second_chance_points int
points_in_the_paint int
fastbreak_points int
bench_points int
largest_lead int
trends chr
team_name chr
game_id chr
date chr
q1 int
q2 int
q3 int
q4 int
total int
time_of_largest_lead chr
ot int
x2ot int
x3ot int
season chr
season_type chr

Examples

try(basketball_team_box_score("m",2018))

Get U SPORTS field hockey pbp

Description

Get U SPORTS field hockey pbp

Usage

field_hockey_pbp(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
time chr
event chr
quarters int
game_id chr
season chr
season_type chr

Examples

try(field_hockey_pbp(2018))

Get U SPORTS field hockey player box scores

Description

Get U SPORTS field hockey player box scores

Usage

field_hockey_player_box_score(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
player chr
team chr
sh int
sog int
g int
a int
ds int
min int
yellow_card int
red_card int
game_id chr
sog_against int
ga int
sv int
goalie_mins chr
game_date chr
season chr
season_type chr

Examples

try(field_hockey_player_box_score(2018))

Get U SPORTS field hockey schedule

Description

Get U SPORTS field hockey schedule

Usage

field_hockey_schedule()

Value

Column Name Type
date chr
away chr
away_score int
home chr
home_score int
status chr
notes chr
month chr
box_scores chr
conference int
division int
exhibition int
post_season int
season chr

Examples

try(field_hockey_schedule())

Get U SPORTS field hockey team box scores

Description

Get U SPORTS field hockey team box scores

Usage

field_hockey_team_box_score(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
player chr
team chr
sh int
sog int
g int
a int
ds int
min int
yellow_card int
red_card int
game_id chr
sog_against int
ga int
sv int
goalie_mins chr
game_date chr
season chr
season_type chr

Examples

try(field_hockey_team_box_score(2018))

Get U SPORTS football defence stats

Description

Get U SPORTS football defence stats

Usage

football_defence(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
number chr
player chr
solo int
ast int
total dbl
sacks dbl
sacks_yds int
tfl dbl
tfl_yds int
ff int
fr int
fr_yds int
int int
int_yds int
br_up int
blks int
qbh int
team chr
game_id chr
season chr
season_type chr

Examples

try(football_defence(2018))

Get U SPORTS football drive summaries

Description

Get U SPORTS football drive summaries

Usage

football_drive_summaries(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
team chr
qtr chr
start chr
poss chr
began chr
plays int
yards int
result chr
away_team chr
home_team chr
game_id chr
season chr
season_type chr

Examples

try(football_drive_summaries(2018))

Get U SPORTS football kicking stats

Description

Get U SPORTS football kicking stats

Usage

football_kicking(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
player chr
punting_no int
punting_yds int
punting_avg dbl
punting_lg int
punting_tb int
in_20 int
kicking_fga int
kicking_fgm int
kicking_lg int
kicking_xpa int
kicking_xpm int
kicking_rg int
kicking_pts int
kickoffs_no int
kickoffs_yds int
kickoffs_avg dbl
kickoffs_tb int
kickoffs_ob int
team chr
game_id chr
season chr
season_type chr

Examples

try(football_kicking(2018))

Get U SPORTS football offence stats

Description

Get U SPORTS football offence stats

Usage

football_offence(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
player chr
c_a chr
passing_yds int
passing_lg int
passing_td int
passing_int int
rtg lgl
rushing_att int
rushing_yds int
rushing_avg dbl
rushing_lg int
rushing_td int
receiving_no int
receiving_yds int
receiving_avg dbl
receiving_lg int
receiving_td int
fumble_no int
fumble_lost int
team chr
game_id chr
season chr
season_type chr

Examples

try(football_offence(2018))

Get U SPORTS football pbp

Description

Get U SPORTS football pbp

Usage

football_pbp(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
downs chr
event chr
quarter chr
game_id chr
away_team chr
home_team chr
season chr
season_type chr

Examples

try(football_pbp(2018))

Get U SPORTS football returns stats

Description

Get U SPORTS football returns stats

Usage

football_returns(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
player chr
punting_returns_no int
punting_returns_yds int
punting_returns_avg dbl
punting_returns_lg int
punting_returns_td int
kickoff_returns_no int
kickoff_returns_yds int
kickoff_returns_avg dbl
kickoff_returns_lg int
kickoff_returns_td int
interception_returns_no int
interception_returns_yds int
interception_returns_avg dbl
interception_returns_lg int
interception_returns_td int
team chr
game_id chr
season chr
season_type chr

Examples

try(football_returns(2018))

Get USPORTS football schedule

Description

Get USPORTS football schedule

Usage

football_schedule()

Value

Column Name Type
league chr
season chr
game_id chr
date Date
exhibition lgl
home_team chr
away_team chr
home_score int
away_score int
game_url chr

Examples

try(football_schedule())

Get U SPORTS football scoring summaries

Description

Get U SPORTS football scoring summaries

Usage

football_scoring_summaries(year = c())

Arguments

year

The season(s) of interest.

Value

Column Name Type
prd chr
time chr
scoring_summary chr
away_score int
home_score int
away_team chr
home_team chr
game_id chr
season chr
season_type chr

Examples

try(football_scoring_summaries(2018))

Get U SPORTS hockey pbp

Description

Get U SPORTS hockey pbp

Usage

hockey_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
event chr
period chr
game_id chr
away_team chr
home_team chr
season chr
season_type chr

Examples

try(hockey_pbp("m",2018))

Get U SPORTS hockey player box scores

Description

Get U SPORTS hockey player box scores

Usage

hockey_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
skaters chr
player_number chr
pos chr
g int
a int
plus_minus int
s int
face_off_won int
face_off_total int
pim int
team chr
ga int
goalie_mins chr
sv int
shots_against int
goalie_pim int
game_id chr
player_links chr
season chr
season_type chr

Examples

try(hockey_player_box_score("m",2018))

Get U SPORTS hockey schedules

Description

Get U SPORTS hockey schedules

Usage

hockey_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

Column Name Type
league chr
season chr
game_id chr
date Date
exhibition lgl
home_team chr
away_team chr
home_score int
away_score int
game_url chr

Examples

try(hockey_schedule("m"))

Get U SPORTS hockey team box scores

Description

Get U SPORTS hockey team box scores

Usage

hockey_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
team chr
goals_p1 int
goals_p2 int
goals_p3 int
goals_pot int
goals_p2ot int
goals_p3ot int
goals_p4ot lgl
goals_total int
shots_1 int
shots_2 int
shots_3 int
shots_total int
shots_ot int
shots_2ot int
shots_3ot int
shots_4ot lgl
game_id chr
season chr
season_type chr

Examples

try(hockey_team_box_score("m",2018))

reads a csv from a url with a csv

Description

reads a csv from a url with a csv

Usage

read_csv(file_url)

Arguments

file_url

A URL to a CSV file.

Value

A data frame with the first few rows of the CSV file.


Get U SPORTS rugby schedule

Description

Get U SPORTS rugby schedule

Usage

rugby_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

try(rugby_schedule("m"))
try(rugby_schedule("w"))

Get U SPORTS soccer play by play data

Description

Get U SPORTS soccer play by play data

Usage

soccer_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
X int
time chr
event chr
game_id chr
away chr
home chr
season chr
season_type chr

Examples

try(soccer_pbp("m",2018))

Get U SPORTS soccer player box score data

Description

Get U SPORTS soccer player box score data

Usage

soccer_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
X int
player chr
sh int
sog int
g int
a int
min int
yellow_card int
red_card int
player_links chr
game_id chr
sog_against int
ga int
sv int
game_date chr
season chr
season_type chr

Examples

try(soccer_player_box_score("m",2018))

Get U SPORTS soccer schedule

Description

Get U SPORTS soccer schedule

Usage

soccer_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

Column Name Type
league chr
season chr
game_id chr
date Date
exhibition lgl
home_team chr
away_team chr
home_score int
away_score int
game_url chr

Examples

try(soccer_schedule("m"))

Get U SPORTS soccer team box score data

Description

Get U SPORTS soccer team box score data

Usage

soccer_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
X int
team chr
goals_1 int
goals_2 int
goals_total int
shots_1 int
shots_2 int
shots_total int
saves_1 int
saves_2 int
saves_total int
fouls_1 int
fouls_2 int
fouls_total int
corners_1 int
corners_2 int
corners_total int
game_date lgl
game_id chr
goals_ot int
goals_2ot int
shots_ot int
shots_2ot int
saves_ot int
saves_2ot int
fouls_ot int
fouls_2ot int
corners_ot int
corners_2ot int
season chr
season_type chr

Examples

try(soccer_team_box_score("m",2018))

Get U SPORTS swimming athletes rankings

Description

Get U SPORTS swimming athletes rankings

Usage

swimming_athlete_rankings()

Value

Column Name Type
Season chr
Gender chr
Rank int
Athlete.University chr
Age chr
Team chr
Conference chr
Date chr
Meet chr
Time chr
FINA int
Event chr
Date.Collected chr

Examples

try(swimming_athlete_rankings())

Get U SPORTS swimming team rankings

Description

Get U SPORTS swimming team rankings

Usage

swimming_team_rankings()

Value

Column Name Type
Rank int
Team chr
Count int
Gender chr
Date chr

Examples

try(swimming_team_rankings())

Get U SPORTS track and field athlete rankings

Description

Get U SPORTS track and field athlete rankings

Usage

tnf_athlete_rankings()

Value

A tibble.

Examples

try(tnf_athlete_rankings())

Get U SPORTS track and field meet results

Description

Get U SPORTS track and field meet results

Usage

tnf_meet_results()

Value

A tibble.

Examples

try(tnf_meet_results())

Get U SPORTS track and field rosters

Description

Get U SPORTS track and field rosters

Usage

tnf_rosters()

Value

A tibble.

Examples

try(tnf_rosters())

Get U SPORTS track and field team rankings

Description

Get U SPORTS track and field team rankings

Usage

tnf_team_rankings()

Value

A tibble.

Examples

try(tnf_team_rankings())

Get U SPORTS track and field universities

Description

Get U SPORTS track and field universities

Usage

tnf_universities()

Value

A tibble.

Examples

try(tnf_universities())

Get U SPORTS volleyball play by play data

Description

Get U SPORTS volleyball play by play data

Usage

volleyball_pbp(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
event chr
home chr
away chr
score chr
set int
game_id chr
season chr
season_type chr

Examples

try(volleyball_pbp("m",2018))

Get U SPORTS volleyball player box scores

Description

Get U SPORTS volleyball player box scores

Usage

volleyball_player_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest.

Value

Column Name Type
player_number chr
player chr
sp chr
k int
e int
ta int
k_percentage dbl
a int
sa int
se int
re int
digs int
bs int
ba int
be int
bhe int
pts dbl
team_name chr
player_links chr
game_id chr
date_time chr
start lgl
season chr
season_type chr

Examples

try(volleyball_player_box_score("m",2018))

Get U SPORTS volleyball schedule

Description

Get U SPORTS volleyball schedule

Usage

volleyball_schedule(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

Column Name Type
league chr
season chr
game_id chr
date Date
exhibition lgl
home_team chr
away_team chr
home_score int
away_score int
game_url chr

Examples

try(volleyball_schedule("m"))

Get U SPORTS volleyball team box scores

Description

Get U SPORTS volleyball team box scores

Usage

volleyball_team_box_score(gender, year = c())

Arguments

gender

Gender of athletes "m" or "w"

year

The season(s) of interest

Value

Column Name Type
set int
k int
e int
ta int
pct dbl
team_name chr
game_id chr
date_time chr
points int
season chr
season_type chr

Examples

try(volleyball_team_box_score("m",2018))

Get U SPORTS wrestling athletes rankings

Description

Get U SPORTS wrestling athletes rankings

Usage

wrestling_athlete_rankings(gender, weight)

Arguments

gender

Gender of athletes "m" or "w"

weight

weight class

Value

A tibble.

Examples

try(wrestling_athlete_rankings("m",90))
try(wrestling_athlete_rankings("w",54))

Get U SPORTS wrestling team rankings

Description

Get U SPORTS wrestling team rankings

Usage

wrestling_team_rankings(gender)

Arguments

gender

Gender of athletes "m" or "w"

Value

A tibble.

Examples

try(wrestling_team_rankings("m"))
try(wrestling_team_rankings("w"))

Get U SPORTS XC meet results

Description

Get U SPORTS XC meet results

Usage

xc_meet_results()

Value

A tibble.

Examples

try(xc_meet_results())

Get U SPORTS XC Rosters

Description

Get U SPORTS XC Rosters

Usage

xc_rosters()

Value

A tibble.

Examples

try(xc_rosters())

Get U SPORTS XC Team Rankings

Description

Get U SPORTS XC Team Rankings

Usage

xc_team_rankings()

Value

A tibble.

Examples

try(xc_team_rankings())

Get U SPORTS XC Teams

Description

Get U SPORTS XC Teams

Usage

xc_universities()

Value

A tibble.

Examples

try(xc_universities())