| Title: | Access U SPORTS data |
|---|---|
| Description: | a package to extract and analyze data from U SPORTS, the governing body of university sport in Canada. |
| Authors: | Shamar Phillips [aut, cre], Matthew Chow [aut] (ORCID: <https://orcid.org/0009-0009-6045-6839>), Rithika Silva [aut], Pierre Aucoin [aut] (ORCID: <https://orcid.org/0009-0003-9739-6485>), David Awosoga [aut] (ORCID: <https://orcid.org/0000-0002-2741-5770>), University of Waterloo Analytics Group for Games and Sports (UWAGGS) [cph] |
| Maintainer: | Shamar Phillips <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-29 07:37:08 UTC |
| Source: | https://github.com/uwaggs/usportsr |
Get U SPORTS basketball pbp data
basketball_pbp(gender, year = c())basketball_pbp(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
basketball_pbp("m",2018)basketball_pbp("m",2018)
Get U SPORTS basketball player box scores
basketball_player_box_score(gender, year = c())basketball_player_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
basketball_player_box_score("m",2018)basketball_player_box_score("m",2018)
Get U SPORTS basketball schedule
basketball_schedule(gender)basketball_schedule(gender)
gender |
Gender of athletes "m" or "w" |
A tibble.
basketball_schedule("m")basketball_schedule("m")
Get U SPORTS basketball team box scores
basketball_team_box_score(gender, year = c())basketball_team_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
basketball_team_box_score("m",2018)basketball_team_box_score("m",2018)
Get U SPORTS field hockey pbp
field_hockey_pbp(year = c())field_hockey_pbp(year = c())
year |
The season(s) of interest. |
A tibble.
field_hockey_pbp(2018)field_hockey_pbp(2018)
Get U SPORTS field hockey player box scores
field_hockey_player_box_score(year = c())field_hockey_player_box_score(year = c())
year |
The season(s) of interest. |
A tibble.
field_hockey_player_box_score(2018)field_hockey_player_box_score(2018)
Get U SPORTS field hockey schedule
field_hockey_schedule()field_hockey_schedule()
A tibble.
field_hockey_schedule()field_hockey_schedule()
Get U SPORTS field hockey team box scores
field_hockey_team_box_score(year = c())field_hockey_team_box_score(year = c())
year |
The season(s) of interest. |
A tibble.
field_hockey_team_box_score(2018)field_hockey_team_box_score(2018)
Get U SPORTS football defence stats
football_defence(year = c())football_defence(year = c())
year |
The season(s) of interest. |
A tibble.
football_defence(2018)football_defence(2018)
Get U SPORTS football drive summaries
football_drive_summaries(year = c())football_drive_summaries(year = c())
year |
The season(s) of interest. |
A tibble.
football_drive_summaries(2018)football_drive_summaries(2018)
Get U SPORTS football kicking stats
football_kicking(year = c())football_kicking(year = c())
year |
The season(s) of interest. |
A tibble.
football_kicking(2018)football_kicking(2018)
Get U SPORTS football offence stats
football_offence(year = c())football_offence(year = c())
year |
The season(s) of interest. |
A tibble.
football_offence(2018)football_offence(2018)
Get U SPORTS football pbp
football_pbp(year = c())football_pbp(year = c())
year |
The season(s) of interest. |
A tibble.
football_pbp(2018)football_pbp(2018)
Get U SPORTS football returns stats
football_returns(year = c())football_returns(year = c())
year |
The season(s) of interest. |
A tibble.
football_returns(2018)football_returns(2018)
Get USPORTS football schedule
football_schedule()football_schedule()
A tibble.
football_schedule()football_schedule()
Get U SPORTS football scoring summaries
football_scoring_summaries(year = c())football_scoring_summaries(year = c())
year |
The season(s) of interest. |
A tibble.
football_scoring_summaries(2018)football_scoring_summaries(2018)
Get U SPORTS hockey pbp
hockey_pbp(gender, year = c())hockey_pbp(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
hockey_pbp("m",2018)hockey_pbp("m",2018)
Get U SPORTS hockey player box scores
hockey_player_box_score(gender, year = c())hockey_player_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
hockey_player_box_score("m",2018)hockey_player_box_score("m",2018)
Get U SPORTS hockey schedules
hockey_schedule(gender)hockey_schedule(gender)
gender |
Gender of athletes "m" or "w" |
A tibble.
hockey_schedule("m")hockey_schedule("m")
Get U SPORTS hockey team box scores
hockey_team_box_score(gender, year = c())hockey_team_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
hockey_team_box_score("m",2018)hockey_team_box_score("m",2018)
reads a csv from a url with a csv
read_csv(file_url)read_csv(file_url)
file_url |
A URL to a CSV file. |
A data frame with the first few rows of the CSV file.
Get U SPORTS rugby schedule
rugby_schedule(gender)rugby_schedule(gender)
gender |
Gender of athletes "m" or "w" |
A tibble.
rugby_schedule("m") rugby_schedule("w")rugby_schedule("m") rugby_schedule("w")
Get U SPORTS soccer play by play data
soccer_pbp(gender, year = c())soccer_pbp(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
soccer_pbp("m",2018)soccer_pbp("m",2018)
Get U SPORTS soccer player box score data
soccer_player_box_score(gender, year = c())soccer_player_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
soccer_player_box_score("m",2018)soccer_player_box_score("m",2018)
Get U SPORTS soccer schedule
soccer_schedule(gender)soccer_schedule(gender)
gender |
Gender of athletes "m" or "w" |
A tibble.
soccer_schedule("m")soccer_schedule("m")
Get U SPORTS soccer team box score data
soccer_team_box_score(gender, year = c())soccer_team_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
soccer_team_box_score("m",2018)soccer_team_box_score("m",2018)
Get U SPORTS swimming athletes rankings
swimming_athlete_rankings()swimming_athlete_rankings()
A tibble.
swimming_athlete_rankings()swimming_athlete_rankings()
Get U SPORTS swimming team rankings
swimming_team_rankings()swimming_team_rankings()
A tibble.
swimming_team_rankings()swimming_team_rankings()
Get U SPORTS track and field athlete rankings
tnf_athlete_rankings()tnf_athlete_rankings()
A tibble.
tnf_athlete_rankings()tnf_athlete_rankings()
Get U SPORTS track and field meet results
tnf_meet_results()tnf_meet_results()
A tibble.
tnf_meet_results()tnf_meet_results()
Get U SPORTS track and field rosters
tnf_rosters()tnf_rosters()
A tibble.
tnf_rosters()tnf_rosters()
Get U SPORTS track and field team rankings
tnf_team_rankings()tnf_team_rankings()
A tibble.
tnf_team_rankings()tnf_team_rankings()
Get U SPORTS track and field universities
tnf_universities()tnf_universities()
A tibble.
tnf_universities()tnf_universities()
Get U SPORTS volleyball play by play data
volleyball_pbp(gender, year = c())volleyball_pbp(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
volleyball_pbp("m",2018)volleyball_pbp("m",2018)
Get U SPORTS volleyball player box scores
volleyball_player_box_score(gender, year = c())volleyball_player_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest. |
A tibble.
volleyball_player_box_score("m",2018)volleyball_player_box_score("m",2018)
Get U SPORTS volleyball schedule
volleyball_schedule(gender)volleyball_schedule(gender)
gender |
Gender of athletes "m" or "w" |
A tibble.
volleyball_schedule("m")volleyball_schedule("m")
Get U SPORTS volleyball team box scores
volleyball_team_box_score(gender, year = c())volleyball_team_box_score(gender, year = c())
gender |
Gender of athletes "m" or "w" |
year |
The season(s) of interest |
A tibble.
volleyball_team_box_score("m",2018)volleyball_team_box_score("m",2018)
Get U SPORTS wrestling athletes rankings
wrestling_athlete_rankings(gender, weight)wrestling_athlete_rankings(gender, weight)
gender |
Gender of athletes "m" or "w" |
weight |
weight class |
A tibble.
wrestling_athlete_rankings("m",90) wrestling_athlete_rankings("w",54)wrestling_athlete_rankings("m",90) wrestling_athlete_rankings("w",54)
Get U SPORTS wrestling team rankings
wrestling_team_rankings(gender)wrestling_team_rankings(gender)
gender |
Gender of athletes "m" or "w" |
A tibble.
wrestling_team_rankings("m") wrestling_team_rankings("w")wrestling_team_rankings("m") wrestling_team_rankings("w")
Get U SPORTS XC meet results
xc_meet_results()xc_meet_results()
A tibble.
xc_meet_results()xc_meet_results()
Get U SPORTS XC Rosters
xc_rosters()xc_rosters()
A tibble.
xc_rosters()xc_rosters()
Get U SPORTS XC Team Rankings
xc_team_rankings()xc_team_rankings()
A tibble.
xc_team_rankings()xc_team_rankings()
Get U SPORTS XC Teams
xc_universities()xc_universities()
A tibble.
xc_universities()xc_universities()